@@ -1,6 +1,19 @@
 import os
 
-DEFAULT_LLM_PROVIDER = "groq"
+DEFAULT_LLM_PROVIDER = "gemini"
+
+# Define API keys from environment variables
+OPENAI_API_KEY = os.getenv("OPENAI_API_KEY", "")
+GROQ_API_KEY = os.getenv("GROQ_API_KEY", "")
+GEMINI_API_KEY = os.getenv("GEMINI_API_KEY", "")
+PERPLEXITY_API_KEY = os.getenv("PERPLEXITY_API_KEY", "")
+
+# Define base URLs for providers
+OPENAI_BASE_URL = None
+GROQ_BASE_URL = "https://api.groq.com/openai/v1"
+GEMINI_BASE_URL = "https://generativelanguage.googleapis.com/v1beta/openai/"
+PERPLEXITY_BASE_URL = "https://api.perplexity.ai"
+
 
 GROQ_MODELS = {
     "default": "meta-llama/llama-4-maverick-17b-128e-instruct",
@@ -14,7 +27,7 @@ OPENAI_MODELS = {
     "4o_MINI": "gpt-4o-mini",
     "41_MINI": "gpt-4.1-mini",
     "41_NANO": "gpt-4.1-nano",
-    "o3": "o3"
+    "o3": "o3",
 }
 
 GEMINI_MODELS = {
@@ -22,7 +35,7 @@ GEMINI_MODELS = {
     "20_FLASH": "gemini-2.0-flash",
     "25_FLASH": "gemini-2.5-flash",
     "25_FLASH_LITE": "gemini-2.5-flash-lite",
-    "25_PRO": "gemini-2.5-pro"
+    "25_PRO": "gemini-2.5-pro",
 }
 
 PERPLEXITY_MODELS = {
@@ -32,23 +45,23 @@ PERPLEXITY_MODELS = {
 
 LLM_PROVIDERS = {
     "openai": {
-        "api_key": os.getenv("OPENAI_API_KEY", ""),
-        "base_url": None,
+        "api_key": OPENAI_API_KEY,
+        "base_url": OPENAI_BASE_URL,
         "models": OPENAI_MODELS,
     },
     "groq": {
-        "api_key": os.getenv("GROQ_API_KEY", ""),
-        "base_url": "https://api.groq.com/openai/v1",
+        "api_key": GROQ_API_KEY,
+        "base_url": GROQ_BASE_URL,
         "models": GROQ_MODELS,
     },
     "gemini": {
-        "api_key": os.getenv("GEMINI_API_KEY", ""),
-        "base_url": "https://generativelanguage.googleapis.com/v1beta/openai/",
+        "api_key": GEMINI_API_KEY,
+        "base_url": GEMINI_BASE_URL,
         "models": GEMINI_MODELS,
     },
     "perplexity": {
-        "api_key": os.getenv("PERPLEXITY_API_KEY", ""),
-        "base_url": "https://api.perplexity.ai",
+        "api_key": PERPLEXITY_API_KEY,
+        "base_url": PERPLEXITY_BASE_URL,
         "models": PERPLEXITY_MODELS,
     },
 }
\ No newline at end of file
