@@ -1,4 +1,3 @@
-import pytest
 from pyagentix.agent import AgentUnit
 from pyagentix.chatbot import Chatbot
 from pyagentix.llm import LLM
@@ -9,6 +8,6 @@ if __name__ == "__main__":
     general_agent = AgentUnit(
         instruction="You are a helpful assistant. Answer the user's questions clearly and concisely.",
     )
-    general_agent.llm.provider = "gemini"
+    general_agent.llm.provider = "openai"
     chatbot = Chatbot(client=general_agent)
-    chatbot.cli_run()
\ No newline at end of file
+    chatbot.cli_run(stream=True)
\ No newline at end of file
